@@ -3,11 +3,10 @@
 
 import time
 import board
-import busio
 from adafruit_apds9960.apds9960 import APDS9960
 from adafruit_apds9960 import colorutility
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()
 apds = APDS9960(i2c)
 apds.enable_color = True
 
